@@ -1,5 +1,5 @@
 use crate::module::common::sys_sig_listener;
-use crate::module::module::{init_log, Module, PrepareError};
+use crate::module::module_impl::{init_log, Module, PrepareError};
 use crate::onto::individual::{Individual, RawObj};
 use crate::onto::parser::parse_raw;
 use crossbeam_channel::{select, tick};
