@@ -88,7 +88,7 @@ pub async fn check_ticket(w_ticket_id: &Option<String>, ticket_cache: &TicketCac
         if let Some(tt) = &db.tt {
             let response = match tt.select(TICKETS_SPACE_ID, 0, &(&ticket_id,), 0, 100, IteratorType::EQ).await {
                 Ok(r) => r,
-                Err(e) => {
+                Err(_) => {
                     return Err(ResultCode::TicketNotFound);
                 },
             };
@@ -118,6 +118,7 @@ pub async fn check_ticket(w_ticket_id: &Option<String>, ticket_cache: &TicketCac
         let user_uri = ticket_obj.user_uri.clone();
         let mut t = ticket_cache.write.lock().await;
         t.insert(ticket_id.to_owned(), ticket_obj);
+        //info!("ticket cache size = {}", t.len());
         t.refresh();
 
         return Ok(user_uri);
